! ------------------------------------------------------------------------------------- !
! Class description:    Mappoint                                                        !
! Version:              1.01                                                            !
! Description:          This class enables mappoint in your application                 !
! --------------------------------------------------------------------------------------!
! Authors:              Roel S.F. Abspoel (roel.abspoel@gmail.com)                      !
!                       William Cirino (w_cirino@hotmail.com)                           !
!                                                                                       !
! Copyright    :        This template and class is freeware and provided                !
!                       'as is'. You are welcome to share this template and             !
!                       class in its origional form. If you make modifications          !
!                       please share these so they can be incorperated into             !
!                       a new public release.                                           !
!                                                                                       !
! ------------------------------------------------------------------------------------- !
  MEMBER
! ------------------------------------------------------------------------------------- !
! Add a map so the compiler will include the definitions for the Run-time library       !
! functions. In other words, using a local MAP in the CLW, the compiler will            !
! automagically include the BUILTINS.CLW file as a module of procedure                  !
! definitions. Without it you would be responsible for creating procedure               !
! definitions for each CLIP, LEFT, etc. function that you end up using just like        !
! you have to for procedures that you write yourself.                                   !
! ------------------------------------------------------------------------------------- !

  MAP
  END

! ------------------------------------------------------------------------------------- !
! Include the INC file to keep it all together                                          !
! ------------------------------------------------------------------------------------- !

  INCLUDE('Mappoint.inc'),ONCE

! ------------------------------------------------------------------------------------- !
MappointClass.Construct PROCEDURE
! Auto constructor
! ------------------------------------------------------------------------------------- !
  CODE

! ------------------------------------------------------------------------------------- !
MappointClass.Destruct PROCEDURE
! Auto desctructor
! ------------------------------------------------------------------------------------- !
  CODE

! ------------------------------------------------------------------------------------- !
MappointClass.Init PROCEDURE(LONG Cname,BYTE RErrors, BYTE StTools,BYTE NaTools,BYTE DrTools,BYTE LoTools,LONG MapChoice,Byte pBorder)
! Initialise OLE/OCX control
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.MPControl = Cname
  SELF.MPControl{Prop:ReportException} = RErrors
  SELF.MPControl{Prop:Create} = 'Mappoint.Control'
  SELF.MapObject   = SELF.MPControl{'Newmap('& MapChoice &')'}
  SELF.IsMapActive = SELF.MPControl{'ActiveMap'}
  SELF.MPControl{'Toolbars.Item("Standard").Visible'} = StTools
  SELF.MPControl{'Toolbars.Item("Navigation").Visible'} = NaTools
  SELF.MPControl{'Toolbars.Item("Drawing").Visible'} = DrTools
  SELF.MPControl{'Toolbars.Item("Location And Scale").Visible'} = LoTools

  If pBorder
    SELF.MPControl{'BorderStyle'} = 1 !'has border
    SELF.MPControl{'Appearance'}  = 1 !'border is 3D
  End

! ------------------------------------------------------------------------------------- !
MappointClass.SetAltitude  PROCEDURE(LONG pAltitude)
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.MPControl{SELF.MapObject & '.Altitude'} = pAltitude

! ------------------------------------------------------------------------------------- !
MappointClass.Save PROCEDURE
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.MPControl{SELF.MapObject &'.Saved'} = TRUE

! ------------------------------------------------------------------------------------- !
MappointClass.AddPinToAddress PROCEDURE(LONG PinNr,STRING TheAddress,STRING TheDesc,STRING TheNote,BYTE ZoomIn,BYTE ShowBalloon)
! Add a pushpin to an adress
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.FoundResults = SELF.MPControl{SELF.MapObject & '.FindResults("' & TheAddress &'").Item(1)'}
  SELF.PushPin = SELF.MPControl{SELF.MapObject &'.AddPushPin('& SELF.FoundResults &', "'& TheDesc &'")'}
  IF ShowBalloon
    SELF.MPControl{SELF.PushPin &'.BalloonState'} = 2
  END
  SELF.MPControl{SELF.PushPin &'.Symbol'} = PinNr
  SELF.MPControl{SELF.PushPin &'.Note'} = TheNote
  IF ZoomIn
    SELF.MPControl{SELF.FoundResults & '.Location.GoTo'}
  END

! ------------------------------------------------------------------------------------- !
MappointClass.AddPinToLocation PROCEDURE(LONG PinNr,STRING Latitude,STRING Longitude,STRING TheDesc,STRING TheNote,BYTE ZoomIn,BYTE ShowBalloon)
! Add a pushpin to an location
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.FoundResults = SELF.MPControl{SELF.MapObject & '.GetLocation("' & Latitude &'","' & Longitude & '")'}
  SELF.PushPin = SELF.MPControl{SELF.MapObject &'.AddPushPin('& SELF.FoundResults &', "'& TheDesc &'")'}
  IF ShowBalloon
    SELF.MPControl{SELF.PushPin &'.BalloonState'} = 2
  END
  SELF.MPControl{SELF.PushPin &'.Symbol'} = PinNr
  SELF.MPControl{SELF.PushPin &'.Note'}   = TheNote
  IF ZoomIn
    SELF.MPControl{SELF.FoundResults & '.Location.GoTo'}
    SELF.MPControl{SELF.MapObject & '.Altitude'} = 1
  END

! ------------------------------------------------------------------------------------- !
MappointClass.ZoomIn PROCEDURE
! Zoom in on location
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.MPControl{SELF.MapObject & '.DataSets.ZoomTo'}

! ------------------------------------------------------------------------------------- !
MappointClass.ZoomToAddress PROCEDURE(STRING TheAddress)
! Zoom in on an adress
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.FoundResults = SELF.MPControl{SELF.MapObject & '.FindResults("' & TheAddress &'").Item(1)'}
  SELF.MPControl{SELF.FoundResults & '.Location.GoTo'}

! ------------------------------------------------------------------------------------- !
MappointClass.ZoomToLocation PROCEDURE(STRING Latitude,STRING Longitude)
! Zoom in on a location
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.FoundResults = SELF.MPControl{SELF.MapObject & '.GetLocation("' & Latitude &'","' & Longitude & '")'}
  SELF.MPControl{SELF.FoundResults & '.Location.GoTo'}
  SELF.MPControl{SELF.MapObject & '.Altitude'} = 1

! ------------------------------------------------------------------------------------- !
MappointClass.RemovePushpin PROCEDURE(STRING PushPin)
! Remove a pushpin
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.ObjPin  = SELF.MPControl{SELF.MapObject & '.FindPushpin("' & Clip(PushPin) & '")'}
  IF SELF.ObjPin
    SELF.MPControl{SELF.ObjPin & '.Delete'}
  ELSE
    MESSAGE('Could not locate the pushpin.|'& CLIP(PushPin),'Cannot delete pushpin',ICON:EXCLAMATION)
  END

! ------------------------------------------------------------------------------------- !
MappointClass.PrintMap PROCEDURE(STRING TheTitle)
! Print the map
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.MPControl{SELF.MapObject & '.PrintOut("","'& TheTitle &'",1,0,0,0,2,0)'}

! ------------------------------------------------------------------------------------- !
MappointClass.OpenMap PROCEDURE()
! Open a map
! ------------------------------------------------------------------------------------- !
MapFile CSTRING(260)
  CODE
  IF Filedialog('Open a map file..',MapFile,'Mappoint files|*.ptm;*.ptt',FILE:KEEPDIR+FILE:LONGNAME)
    SELF.MPControl{'OpenMap("'& MapFile &'")'}
  END

! ------------------------------------------------------------------------------------- !
MappointClass.SaveMap PROCEDURE()
! Save a map
! ------------------------------------------------------------------------------------- !
MapFile CSTRING(260)
  CODE
  IF Filedialog('Save a map file..',MapFile,'Mappoint|*.ptm',FILE:SAVE+FILE:KEEPDIR+FILE:LONGNAME)
    SELF.MPControl{SELF.IsMapActive &'.SaveAs("'& MapFile &'",0)'}
  END

! ------------------------------------------------------------------------------------- !
MappointClass.FindDialog PROCEDURE(STRING FindText,LONG FindType)
! Open the find dialog
! ------------------------------------------------------------------------------------- !
  CODE

   SELF.MPControl{SELF.MapObject & '.ShowFindDialog("'& FindText &'",'& FindType &','& 0{PROP:HANDLE} &')'}
!  SELF.MPControl{SELF.MapObject & '.ShowFindDialog("'& FindText &'",'& FindType &')'}

! ------------------------------------------------------------------------------------- !
MappointClass.AllowEdgePanning PROCEDURE(BYTE pAllowEdgepanning)
!Enable or Disable Edge panning of map
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.MPControl{SELF.MapObject &'.AllowEdgePan'} = pAllowEdgePanning

! ------------------------------------------------------------------------------------- !
MappointClass.DragBehavior PROCEDURE(BYTE pState)
!Change state panning of map
! ------------------------------------------------------------------------------------- !
  CODE
  SELF.MPControl{SELF.MapObject &'.DragBehavior'} = pState


! ------------------------------------------------------------------------------------- !
MappointClass.StandardToolbar PROCEDURE()
! ------------------------------------------------------------------------------------- !
  CODE
      if SELF.MPControl{'Toolbars.Item("Standard").Visible'} = -1
         SELF.MPControl{'Toolbars.Item("Standard").Visible'} = 0
      Elsif SELF.MPControl{'Toolbars.Item("Standard").Visible'} = 0
         SELF.MPControl{'Toolbars.Item("Standard").Visible'} = -1
      End

! ------------------------------------------------------------------------------------- !
MappointClass.NavigationToolbar PROCEDURE()
! ------------------------------------------------------------------------------------- !
  CODE
      if SELF.MPControl{'Toolbars.Item("Navigation").Visible'} = -1
         SELF.MPControl{'Toolbars.Item("Navigation").Visible'} = 0
      Elsif SELF.MPControl{'Toolbars.Item("Navigation").Visible'} = 0
            SELF.MPControl{'Toolbars.Item("Navigation").Visible'} = -1
      End

! ------------------------------------------------------------------------------------- !
MappointClass.DrawingToolbar PROCEDURE()
! ------------------------------------------------------------------------------------- !
  CODE
     if SELF.MPControl{'Toolbars.Item("Drawing").Visible'} = -1
        SELF.MPControl{'Toolbars.Item("Drawing").Visible'} = 0
     elsif SELF.MPControl{'Toolbars.Item("Drawing").Visible'} = 0
           SELF.MPControl{'Toolbars.Item("Drawing").Visible'} = -1
     End

! ------------------------------------------------------------------------------------- !
MappointClass.LocationScaleToolbar PROCEDURE()
! ------------------------------------------------------------------------------------- !
  CODE
     if SELF.MPControl{'Toolbars.Item("Location And Scale").Visible'} = -1
        SELF.MPControl{'Toolbars.Item("Location And Scale").Visible'} = 0
     Elsif SELF.MPControl{'Toolbars.Item("Location And Scale").Visible'} = 0
           SELF.MPControl{'Toolbars.Item("Location And Scale").Visible'} = -1
     End
! ------------------------------------------------------------------------------------- !